@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2020 - 2021 TU Wien.
+# Copyright (C) 2020-2022 TU Wien.
 #
 # Invenio-Theme-TUW is free software; you can redistribute it and/or modify
 # it under the terms of the MIT License; see LICENSE file for more details.
@@ -13,8 +13,20 @@ THEME_TUW_MATOMO_ENABLED = True
 THEME_TUW_MATOMO_URL = "https://s191.dl.hpc.tuwien.ac.at/"
 """The URL under which Matomo is reachable."""
 
-THEME_TUW_DISPLAY_STAGING_WARNING = False
-"""Whether or not to display a warning that it's the staging system."""
+THEME_TUW_MATOMO_SITE_ID = "1"
+"""An identifier for the site, to be used by Matomo."""
+
+THEME_TUW_HEADER_WARNING = None
+"""The (HTML-formatted) message to display in the header.
+
+A value of ``None`` (which is the default) causes the message box to not be displayed.
+"""
+
+THEME_TUW_FRONTPAGE_WARNING = None
+"""The (HTML-formatted) message to display in the frontpage.
+
+A value of ``None`` (which is the default) causes the message box to not be displayed.
+"""
 
 THEME_TUW_CONTACT_EMAIL = "tudata@tuwien.ac.at"
 """The e-mail address provided as contact."""
